@@ -4,6 +4,15 @@ import mock
 SOURCE_FILE = 'tests/cobertura.xml'
 
 
+def remove_style_tag(html):
+    style_pattern_start = '\n    <style>'
+    style_pattern_stop = '\n    </style>'
+    style_starts = html.find(style_pattern_start)
+    style_stops = html.find(style_pattern_stop) + len(style_pattern_stop)
+    html_nostyle = html[:style_starts] + html[style_stops:]
+    return html_nostyle
+
+
 def make_cobertura(xml_file=SOURCE_FILE):
     from pycobertura import Cobertura
     cobertura = Cobertura(xml_file)
@@ -198,42 +207,7 @@ dummy/dummy2  -        -1      +50.00%  -2
 TOTAL         -        -       -"""
 
 
-@mock.patch('pycobertura.utils.sys.stdout.isatty', return_value=True)
-def test_text_report_delta__colorize_for_tty(mock_tty):
-    from pycobertura.reporters import TextReporterDelta
-
-    cobertura1 = make_cobertura('tests/dummy.with-dummy2-better-cov.xml')
-    cobertura2 = make_cobertura('tests/dummy.with-dummy2-better-and-worse.xml')
-
-    report_delta = TextReporterDelta(cobertura1, cobertura2)
-
-    assert report_delta.generate() == """\
-Name          Stmts    Miss    Cover    Missing
-------------  -------  ------  -------  ---------
-dummy/dummy   -        +1      -25.00%  \x1b[31m+5\x1b[39m
-dummy/dummy2  -        -1      +50.00%  \x1b[32m-2\x1b[39m
-TOTAL         -        -       -"""
-
-
-@mock.patch('pycobertura.utils.sys.stdout.isatty', return_value=False)
-def test_text_report_delta__no_colorize_for_non_tty(mock_tty):
-    from pycobertura.reporters import TextReporterDelta
-
-    cobertura1 = make_cobertura('tests/dummy.with-dummy2-better-cov.xml')
-    cobertura2 = make_cobertura('tests/dummy.with-dummy2-better-and-worse.xml')
-
-    report_delta = TextReporterDelta(cobertura1, cobertura2)
-
-    assert report_delta.generate() == """\
-Name          Stmts    Miss    Cover    Missing
-------------  -------  ------  -------  ---------
-dummy/dummy   -        +1      -25.00%  +5
-dummy/dummy2  -        -1      +50.00%  -2
-TOTAL         -        -       -"""
-
-
-@mock.patch('pycobertura.utils.sys.stdout.isatty', return_value=True)
-def test_text_report_delta__force_colorize_when_tty_is_true(mock_tty):
+def test_text_report_delta__colorize_True():
     from pycobertura.reporters import TextReporterDelta
 
     cobertura1 = make_cobertura('tests/dummy.with-dummy2-better-cov.xml')
@@ -249,42 +223,7 @@ dummy/dummy2  -        -1      +50.00%  \x1b[32m-2\x1b[39m
 TOTAL         -        -       -"""
 
 
-@mock.patch('pycobertura.utils.sys.stdout.isatty', return_value=False)
-def test_text_report_delta__force_colorize_when_tty_is_false(mock_tty):
-    from pycobertura.reporters import TextReporterDelta
-
-    cobertura1 = make_cobertura('tests/dummy.with-dummy2-better-cov.xml')
-    cobertura2 = make_cobertura('tests/dummy.with-dummy2-better-and-worse.xml')
-
-    report_delta = TextReporterDelta(cobertura1, cobertura2, color=True)
-
-    assert report_delta.generate() == """\
-Name          Stmts    Miss    Cover    Missing
-------------  -------  ------  -------  ---------
-dummy/dummy   -        +1      -25.00%  \x1b[31m+5\x1b[39m
-dummy/dummy2  -        -1      +50.00%  \x1b[32m-2\x1b[39m
-TOTAL         -        -       -"""
-
-
-@mock.patch('pycobertura.utils.sys.stdout.isatty', return_value=True)
-def test_text_report_delta__force_no_colorize_when_tty_is_true(mock_tty):
-    from pycobertura.reporters import TextReporterDelta
-
-    cobertura1 = make_cobertura('tests/dummy.with-dummy2-better-cov.xml')
-    cobertura2 = make_cobertura('tests/dummy.with-dummy2-better-and-worse.xml')
-
-    report_delta = TextReporterDelta(cobertura1, cobertura2, color=False)
-
-    assert report_delta.generate() == """\
-Name          Stmts    Miss    Cover    Missing
-------------  -------  ------  -------  ---------
-dummy/dummy   -        +1      -25.00%  +5
-dummy/dummy2  -        -1      +50.00%  -2
-TOTAL         -        -       -"""
-
-
-@mock.patch('pycobertura.utils.sys.stdout.isatty', return_value=False)
-def test_text_report_delta__force_no_colorize_when_tty_is_false(mock_tty):
+def test_text_report_delta__colorize_False():
     from pycobertura.reporters import TextReporterDelta
 
     cobertura1 = make_cobertura('tests/dummy.with-dummy2-better-cov.xml')
@@ -305,8 +244,12 @@ def test_html_report():
 
     cobertura = make_cobertura()
     report = HtmlReporter(cobertura)
+    html_output = report.generate()
 
-    assert report.generate() == """\
+    assert "normalize.css" in html_output
+    assert "Skeleton V2.0" in html_output
+
+    assert remove_style_tag(html_output) == """\
 <html>
   <head>
     <title>pycobertura report</title>
@@ -367,16 +310,17 @@ def test_html_report_delta():
     cobertura2 = make_cobertura('tests/dummy.with-dummy2-no-cov.xml')
 
     report_delta = HtmlReporterDelta(cobertura1, cobertura2)
+    html_output = report_delta.generate()
+    assert '.red {color: red}' in html_output
+    assert '.green {color: green}' in html_output
+    assert "normalize.css" in html_output
+    assert "Skeleton V2.0" in html_output
 
-    assert report_delta.generate() == """\
+    assert remove_style_tag(html_output) == """\
 <html>
   <head>
     <title>pycobertura report</title>
     <meta charset="UTF-8">
-    <style>
-.red {color: red}
-.green {color: green}
-    </style>
   </head>
   <body>
     <table>
